package gd_management

import (
	"context"
	"fmt"
	"time"

	"github.com/smallnest/rpcx/client"
	"github.com/smallnest/rpcx/protocol"
	"github.com/smallnest/rpcx/share"
)

type GdManagementXClient struct {
	xcli client.XClient
}

func (a *GdManagementXClient) Init(etcdAddrs []string, basePath, servicePath string) {
	opt := client.Option{
		Retries:        3,
		RPCPath:        share.DefaultRPCPath,
		ConnectTimeout: 10 * time.Second,
		SerializeType:  protocol.JSON,
		CompressType:   protocol.None,
		BackupLatency:  10 * time.Millisecond,
	}

	//if runtime.GOOS == "windows" {
	//	d := client.NewEtcdDiscovery(fmt.Sprintf("/%s", basePath), servicePath, etcdAddrs, nil)
	//	a.xcli = client.NewXClient(servicePath, client.Failtry, client.RandomSelect, d, opt)
	//} else {

	d := client.NewEtcdDiscovery(basePath, servicePath, etcdAddrs, nil)
	a.xcli = client.NewXClient(servicePath, client.Failtry, client.RandomSelect, d, opt)
	//}
}

func (a *GdManagementXClient) InitForK8s(servicePath string, k8sServiceName string, k8sServicePort string) {
	opt := client.Option{
		Retries:        1,
		RPCPath:        share.DefaultRPCPath,
		ConnectTimeout: 10 * time.Second,
		SerializeType:  protocol.JSON,
		CompressType:   protocol.None,
		BackupLatency:  10 * time.Millisecond,
	}
	sd := client.NewPeer2PeerDiscovery(fmt.Sprintf("tcp@%s:%s", k8sServiceName, k8sServicePort), "")
	a.xcli = client.NewXClient(servicePath, client.Failtry, client.RandomSelect, sd, opt)
}

func (a *GdManagementXClient) ManagementAddBaseApi(ctx context.Context, req *ManagementAddBaseApiReq) (reply ManagementAddBaseApiReply, err error) {
	err = a.xcli.Call(ctx, "ManagementAddBaseApi", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementDelBaseApi(ctx context.Context, req *ManagementDelBaseApiReq) (reply ManagementDelBaseApiReply, err error) {
	err = a.xcli.Call(ctx, "ManagementDelBaseApi", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementUpdateBaseApi(ctx context.Context, req *ManagementUpdateBaseApiReq) (reply ManagementUpdateBaseApiReply, err error) {
	err = a.xcli.Call(ctx, "ManagementUpdateBaseApi", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementGetBaseApiList(ctx context.Context, req *ManagementGetBaseApiListReq) (reply ManagementGetBaseApiListReply, err error) {
	err = a.xcli.Call(ctx, "ManagementGetBaseApiList", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementGetBaseApiInfo(ctx context.Context, req *ManagementGetBaseApiInfoReq) (reply ManagementGetBaseApiInfoReply, err error) {
	err = a.xcli.Call(ctx, "ManagementGetBaseApiInfo", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementSetBaseApiState(ctx context.Context, req *ManagementSetBaseApiStateReq) (reply ManagementSetBaseApiStateReply, err error) {
	err = a.xcli.Call(ctx, "ManagementSetBaseApiState", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementAddError(ctx context.Context, req *ManagementAddErrorReq) (reply ManagementAddErrorReply, err error) {
	err = a.xcli.Call(ctx, "ManagementAddError", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementDelError(ctx context.Context, req *ManagementDelErrorReq) (reply ManagementDelErrorReply, err error) {
	err = a.xcli.Call(ctx, "ManagementDelError", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementUpdateError(ctx context.Context, req *ManagementUpdateErrorReq) (reply ManagementUpdateErrorReply, err error) {
	err = a.xcli.Call(ctx, "ManagementUpdateError", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementGetErrorList(ctx context.Context, req *ManagementGetErrorListReq) (reply ManagementGetErrorListReply, err error) {
	err = a.xcli.Call(ctx, "ManagementGetErrorList", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementAddBaseApiProvider(ctx context.Context, req *ManagementAddBaseApiProviderReq) (reply ManagementAddBaseApiProviderReply, err error) {
	err = a.xcli.Call(ctx, "ManagementAddBaseApiProvider", req, &reply)
	return
}

/*func (a *GdManagementXClient) ManagementDelBaseApiProvider(ctx context.Context, req *ManagementDelBaseApiProviderReq) (reply ManagementDelBaseApiProviderReply, err error) {
	err = a.xcli.Call(ctx, "ManagementDelBaseApiProvider", req, &reply)
	return
}
*/
func (a *GdManagementXClient) ManagementGetBaseApiProviderList(ctx context.Context, req *ManagementGetBaseApiProviderListReq) (reply ManagementGetBaseApiProviderListReply, err error) {
	err = a.xcli.Call(ctx, "ManagementGetBaseApiProviderList", req, &reply)
	return
}

/*
func (a *GdManagementXClient) ManagementSetBaseApiProviderPriority(ctx context.Context, req *ManagementSetBaseApiProviderPriorityReq) (reply ManagementSetBaseApiProviderPriorityReply, err error) {
	err = a.xcli.Call(ctx, "ManagementSetBaseApiProviderPriority", req, &reply)
	return
}
*/

func (a *GdManagementXClient) ManagementAddProviderPlatform(ctx context.Context, req *ManagementAddProviderPlatformReq) (reply ManagementAddProviderPlatformReply, err error) {
	err = a.xcli.Call(ctx, "ManagementAddProviderPlatform", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementDelProviderPlatform(ctx context.Context, req *ManagementDelProviderPlatformReq) (reply ManagementDelProviderPlatformReply, err error) {
	err = a.xcli.Call(ctx, "ManagementDelProviderPlatform", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementUpdateProviderPlatform(ctx context.Context, req *ManagementUpdateProviderPlatformReq) (reply ManagementUpdateProviderPlatformReply, err error) {
	err = a.xcli.Call(ctx, "ManagementUpdateProviderPlatform", req, &reply)
	return
}
func (a *GdManagementXClient) ManagementGetProviderPlatformList(ctx context.Context, req *ManagementGetProviderPlatformListReq) (reply ManagementGetProviderPlatformListReply, err error) {
	err = a.xcli.Call(ctx, "ManagementGetProviderPlatformList", req, &reply)
	return
}
func (a *GdManagementXClient) ManagementAddProviderApi(ctx context.Context, req *ManagementAddProviderApiReq) (reply ManagementAddProviderApiReply, err error) {
	err = a.xcli.Call(ctx, "ManagementAddProviderApi", req, &reply)
	return
}
func (a *GdManagementXClient) ManagementDelProviderApi(ctx context.Context, req *ManagementDelProviderApiReq) (reply ManagementDelProviderApiReply, err error) {
	err = a.xcli.Call(ctx, "ManagementDelProviderApi", req, &reply)
	return
}
func (a *GdManagementXClient) ManagementUpdateProviderApi(ctx context.Context, req *ManagementUpdateProviderApiReq) (reply ManagementUpdateProviderApiReply, err error) {
	err = a.xcli.Call(ctx, "ManagementUpdateProviderApi", req, &reply)
	return
}
func (a *GdManagementXClient) ManagementGetProviderApiList(ctx context.Context, req *ManagementGetProviderApiListReq) (reply ManagementGetProviderApiListReply, err error) {
	err = a.xcli.Call(ctx, "ManagementGetProviderApiList", req, &reply)
	return
}
func (a *GdManagementXClient) DataApiAddApi(ctx context.Context, req *ManagementDataApiAddApiReq) (reply ManagementDataApiAddApiReply, err error) {
	err = a.xcli.Call(ctx, "DataApiAddApi", req, &reply)
	return
}
func (a *GdManagementXClient) DataApiDeleteApi(ctx context.Context, req *ManagementDataApiDeleteApiReq) (reply ManagementDataApiDeleteApiReply, err error) {
	err = a.xcli.Call(ctx, "DataApiDeleteApi", req, &reply)
	return
}
func (a *GdManagementXClient) DataApiModifyApi(ctx context.Context, req *ManagementDataApiModifyApiReq) (reply ManagementDataApiModifyApiReply, err error) {
	err = a.xcli.Call(ctx, "DataApiModifyApi", req, &reply)
	return
}
func (a *GdManagementXClient) DataApiGetAll(ctx context.Context, req *ManagementDataApiGetAllReq) (reply ManagementDataApiGetAllReply, err error) {
	err = a.xcli.Call(ctx, "DataApiGetAll", req, &reply)
	return
}
func (a *GdManagementXClient) DataApiGetApiInfo(ctx context.Context, req *ManagementDataApiGetApiInfoReq) (reply ManagementDataApiGetApiInfoReply, err error) {
	err = a.xcli.Call(ctx, "DataApiGetApiInfo", req, &reply)
	return
}
func (a *GdManagementXClient) DataApiReleaseApi(ctx context.Context, req *ManagementDataApiReleaseApiReq) (reply ManagementDataApiReleaseApiReply, err error) {
	err = a.xcli.Call(ctx, "DataApiReleaseApi", req, &reply)
	return
}
func (a *GdManagementXClient) DataApiAddQueryType(ctx context.Context, req *ManagementDataApiAddQueryTypeReq) (reply ManagementDataApiAddQueryTypeReply, err error) {
	err = a.xcli.Call(ctx, "DataApiAddQueryType", req, &reply)
	return
}
func (a *GdManagementXClient) DataApiModifyQueryType(ctx context.Context, req *ManagementDataApiModifyQueryTypeReq) (reply ManagementDataApiModifyQueryTypeReply, err error) {
	err = a.xcli.Call(ctx, "DataApiModifyQueryType", req, &reply)
	return
}
func (a *GdManagementXClient) DataApiRemoveQueryType(ctx context.Context, req *ManagementDataApiRemoveQueryTypeReq) (reply ManagementDataApiRemoveQueryTypeReply, err error) {
	err = a.xcli.Call(ctx, "DataApiRemoveQueryType", req, &reply)
	return
}
func (a *GdManagementXClient) DataApiGetQueryType(ctx context.Context, req *ManagementDataApiGetQueryTypeReq) (reply ManagementDataApiGetQueryTypeReply, err error) {
	err = a.xcli.Call(ctx, "DataApiGetQueryType", req, &reply)
	return
}
func (a *GdManagementXClient) DataApiAddBaseApi(ctx context.Context, req *ManagementDataApiAddBaseApiReq) (reply ManagementDataApiAddBaseApiReply, err error) {
	err = a.xcli.Call(ctx, "DataApiAddBaseApi", req, &reply)
	return
}
func (a *GdManagementXClient) DataApiRemoveBaseApi(ctx context.Context, req *ManagementDataApiRemoveBaseApiReq) (reply ManagementDataApiRemoveBaseApiReply, err error) {
	err = a.xcli.Call(ctx, "DataApiRemoveBaseApi", req, &reply)
	return
}
func (a *GdManagementXClient) DataApiModifyBaseApi(ctx context.Context, req *ManagementDataApiModifyBaseApiReq) (reply ManagementDataApiModifyBaseApiReply, err error) {
	err = a.xcli.Call(ctx, "DataApiModifyBaseApi", req, &reply)
	return
}
func (a *GdManagementXClient) DataApiGetBaseApi(ctx context.Context, req *ManagementDataApiGetBaseApiReq) (reply ManagementDataApiGetBaseApiReply, err error) {
	err = a.xcli.Call(ctx, "DataApiGetBaseApi", req, &reply)
	return
}

/*func (a *GdManagementXClient) DataApiChangeBaseApiIndex(ctx context.Context, req *ManagementDataApiChangeBaseApiIndexReq) (reply ManagementDataApiChangeBaseApiIndexReply, err error) {
	err = a.xcli.Call(ctx, "DataApiChangeBaseApiIndex", req, &reply)
	return
}*/
func (a *GdManagementXClient) DataApiAddDataCombo(ctx context.Context, req *ManagementDataApiAddDataComboReq) (reply ManagementDataApiAddDataComboReply, err error) {
	err = a.xcli.Call(ctx, "DataApiAddDataCombo", req, &reply)
	return
}

func (a *GdManagementXClient) DataApiRemoveDataCombo(ctx context.Context, req *ManagementDataApiRemoveDataComboReq) (reply ManagementDataApiRemoveDataComboReply, err error) {
	err = a.xcli.Call(ctx, "DataApiRemoveDataCombo", req, &reply)
	return
}
func (a *GdManagementXClient) DataApiGetDataCombo(ctx context.Context, req *ManagementDataApiGetDataComboReq) (reply ManagementDataApiGetDataComboReply, err error) {
	err = a.xcli.Call(ctx, "DataApiGetDataCombo", req, &reply)
	return
}

/*func (a *GdManagementXClient) DataApiChooseProviderApi(ctx context.Context, req *ManagementDataApiChooseProviderApiReq) (reply ManagementDataApiChooseProviderApiReply, err error) {
	err = a.xcli.Call(ctx, "DataApiChooseProviderApi", req, &reply)
	return
}
*/
func (a *GdManagementXClient) ManagementAddUserMerchant(ctx context.Context, req *ManagementAddUserMerchantReq) (reply ManagementAddUserMerchantReply, err error) {
	err = a.xcli.Call(ctx, "ManagementAddUserMerchant", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementUpdateUserMerchant(ctx context.Context, req *ManagementUpdateUserMerchantReq) (reply ManagementUpdateUserMerchantReply, err error) {
	err = a.xcli.Call(ctx, "ManagementUpdateUserMerchant", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementGetUserMerchantList(ctx context.Context, req *ManagementGetUserMerchantListReq) (reply ManagementGetUserMerchantListReply, err error) {
	err = a.xcli.Call(ctx, "ManagementGetUserMerchantList", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementSetUserMerchantAuthState(ctx context.Context, req *ManagementSetUserMerchantAuthStateReq) (reply ManagementSetUserMerchantAuthStateReply, err error) {
	err = a.xcli.Call(ctx, "ManagementSetUserMerchantAuthState", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementGetMerchantDataApiList(ctx context.Context, req *ManagementGetMerchantDataApiListReq) (reply ManagementGetMerchantDataApiListReply, err error) {
	err = a.xcli.Call(ctx, "ManagementGetMerchantDataApiList", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementGetMerchantDataApiListByTotal(ctx context.Context, req *ManagementGetMerchantDataApiListByTotalReq) (reply ManagementGetMerchantDataApiListByTotalReply, err error) {
	err = a.xcli.Call(ctx, "ManagementGetMerchantDataApiListByTotal", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementGetMerchantDataApiListByDay(ctx context.Context, req *ManagementGetMerchantDataApiListByDayReq) (reply ManagementGetMerchantDataApiListByDayReply, err error) {
	err = a.xcli.Call(ctx, "ManagementGetMerchantDataApiListByDay", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementGetMerchantBaseApiList(ctx context.Context, req *ManagementGetMerchantBaseApiListReq) (reply ManagementGetMerchantBaseApiListReply, err error) {
	err = a.xcli.Call(ctx, "ManagementGetMerchantBaseApiList", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementGetMerchantBaseApiInfo(ctx context.Context, req *ManagementGetMerchantBaseApiInfoReq) (reply ManagementGetMerchantBaseApiInfoReply, err error) {
	err = a.xcli.Call(ctx, "ManagementGetMerchantBaseApiInfo", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementAddMerchantBaseApi(ctx context.Context, req *ManagementAddMerchantBaseApiReq) (reply ManagementAddMerchantBaseApiReply, err error) {
	err = a.xcli.Call(ctx, "ManagementAddMerchantBaseApi", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementDelMerchantBaseApi(ctx context.Context, req *ManagementDelMerchantBaseApiReq) (reply ManagementDelMerchantBaseApiReply, err error) {
	err = a.xcli.Call(ctx, "ManagementDelMerchantBaseApi", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementUpdateMerchantBaseApi(ctx context.Context, req *ManagementUpdateMerchantBaseApiReq) (reply ManagementUpdateMerchantBaseApiReply, err error) {
	err = a.xcli.Call(ctx, "ManagementUpdateMerchantBaseApi", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementSetMerchantBaseApiPriority(ctx context.Context, req *ManagementSetMerchantBaseApiPriorityReq) (reply ManagementSetMerchantBaseApiPriorityReply, err error) {
	err = a.xcli.Call(ctx, "ManagementSetMerchantBaseApiPriority", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementSetMerchantDataApiQuota(ctx context.Context, req *ManagementSetMerchantDataApiQuotaReq) (reply ManagementSetMerchantDataApiQuotaReply, err error) {
	err = a.xcli.Call(ctx, "ManagementSetMerchantDataApiQuota", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementAddOrder(ctx context.Context, req *ManagementAddOrderReq) (reply ManagementAddOrderReply, err error) {
	err = a.xcli.Call(ctx, "ManagementAddOrder", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementPayOrder(ctx context.Context, req *ManagementPayOrderReq) (reply ManagementPayOrderReply, err error) {
	err = a.xcli.Call(ctx, "ManagementPayOrder", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementGetMerchantOrderList(ctx context.Context, req *ManagementGetMerchantOrderListReq) (reply ManagementGetMerchantOrderListReply, err error) {
	err = a.xcli.Call(ctx, "ManagementGetMerchantOrderList", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementSetMerchantOrderPrice(ctx context.Context, req *ManagementSetMerchantOrderPriceReq) (reply ManagementSetMerchantOrderPriceReply, err error) {
	err = a.xcli.Call(ctx, "ManagementSetMerchantOrderPrice", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementDataApiSetFreeDataCombo(ctx context.Context, req *ManagementDataApiSetFreeDataComboReq) (reply ManagementDataApiSetFreeDataComboReply, err error) {
	err = a.xcli.Call(ctx, "DataApiSetFreeDataCombo", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementDataApiGetQueryTypeList(ctx context.Context, req *ManagementDataApiGetQueryTypeListReq) (reply ManagementDataApiGetQueryTypeListReply, err error) {
	err = a.xcli.Call(ctx, "DataApiGetQueryTypeList", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementGetMerchantDataApiQuota(ctx context.Context, req *ManagementGetMerchantDataApiQuotaReq) (reply ManagementGetMerchantDataApiQuotaReply, err error) {
	err = a.xcli.Call(ctx, "ManagementGetMerchantDataApiQuota", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementGetAllProviderApi(ctx context.Context, req *ManagementGetAllProviderApiReq) (reply ManagementGetAllProviderApiReply, err error) {
	err = a.xcli.Call(ctx, "ManagementGetAllProviderApi", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementQueryTypeBaseApiList(ctx context.Context, req *ManagementQueryTypeBaseApiListReq) (reply ManagementQueryTypeBaseApiListReply, err error) {
	err = a.xcli.Call(ctx, "ManagementQueryTypeBaseApiList", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementDataApiComboList(ctx context.Context, req *ManagementDataApiComboListReq) (reply ManagementDataApiComboListReply, err error) {
	err = a.xcli.Call(ctx, "ManagementDataApiComboList", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementAddMerchantDataApi(ctx context.Context, req *ManagementAddMerchantDataApiReq) (reply ManagementAddMerchantDataApiReply, err error) {
	err = a.xcli.Call(ctx, "ManagementAddMerchantDataApi", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementAddH5Api(ctx context.Context, req *ManagementAddH5ApiReq) (reply ManagementAddH5ApiReply, err error) {
	err = a.xcli.Call(ctx, "ManagementAddH5Api", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementDelH5Api(ctx context.Context, req *ManagementDelH5ApiReq) (reply ManagementDelH5ApiReply, err error) {
	err = a.xcli.Call(ctx, "ManagementDelH5Api", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementUpdateH5Api(ctx context.Context, req *ManagementUpdateH5ApiReq) (reply ManagementUpdateH5ApiReply, err error) {
	err = a.xcli.Call(ctx, "ManagementUpdateH5Api", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementSetH5ApiState(ctx context.Context, req *ManagementSetH5ApiStateReq) (reply ManagementSetH5ApiStateReply, err error) {
	err = a.xcli.Call(ctx, "ManagementSetH5ApiState", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementGetH5ApiList(ctx context.Context, req *ManagementGetH5ApiListReq) (reply ManagementGetH5ApiListReply, err error) {
	err = a.xcli.Call(ctx, "ManagementGetH5ApiList", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementH5ApiAddBaseApi(ctx context.Context, req *ManagementH5ApiAddBaseApiReq) (reply ManagementH5ApiAddBaseApiReply, err error) {
	err = a.xcli.Call(ctx, "ManagementH5ApiAddBaseApi", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementAddH5Service(ctx context.Context, req *ManagementAddH5ServiceReq) (reply ManagementAddH5ServiceReply, err error) {
	err = a.xcli.Call(ctx, "ManagementAddH5Service", req, &reply)
	return
}
func (a *GdManagementXClient) ManagementReleaseH5Service(ctx context.Context, req *ManagementReleaseH5ServiceReq) (reply ManagementReleaseH5ServiceReply, err error) {
	err = a.xcli.Call(ctx, "ManagementReleaseH5Service", req, &reply)
	return
}
func (a *GdManagementXClient) ManagementUpdateH5Service(ctx context.Context, req *ManagementUpdateH5ServiceReq) (reply ManagementUpdateH5ServiceReply, err error) {
	err = a.xcli.Call(ctx, "ManagementUpdateH5Service", req, &reply)
	return
}
func (a *GdManagementXClient) ManagementDelH5Service(ctx context.Context, req *ManagementDelH5ServiceReq) (reply ManagementDelH5ServiceReply, err error) {
	err = a.xcli.Call(ctx, "ManagementDelH5Service", req, &reply)
	return
}
func (a *GdManagementXClient) ManagementGetH5ServiceList(ctx context.Context, req *ManagementGetH5ServiceListReq) (reply ManagementGetH5ServiceListReply, err error) {
	err = a.xcli.Call(ctx, "ManagementGetH5ServiceList", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementH5ServiceAddH5Api(ctx context.Context, req *ManagementH5ServiceAddH5ApiReq) (reply ManagementH5ServiceAddH5ApiReply, err error) {
	err = a.xcli.Call(ctx, "ManagementH5ServiceAddH5Api", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementH5ServiceGetH5ApiList(ctx context.Context, req *ManagementH5ServiceGetH5ApiListReq) (reply ManagementH5ServiceGetH5ApiListReply, err error) {
	err = a.xcli.Call(ctx, "ManagementH5ServiceGetH5ApiList", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementH5ServiceAddCombo(ctx context.Context, req *ManagementH5ServiceAddComboReq) (reply ManagementH5ServiceAddComboReply, err error) {
	err = a.xcli.Call(ctx, "ManagementH5ServiceAddCombo", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementH5ServiceUpdateCombo(ctx context.Context, req *ManagementH5ServiceUpdateComboReq) (reply ManagementH5ServiceUpdateComboReply, err error) {
	err = a.xcli.Call(ctx, "ManagementH5ServiceUpdateCombo", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementH5ServiceGetComboList(ctx context.Context, req *ManagementH5ServiceGetComboListReq) (reply ManagementH5ServiceGetComboListReply, err error) {
	err = a.xcli.Call(ctx, "ManagementH5ServiceGetComboList", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementH5ServiceDelCombo(ctx context.Context, req *ManagementH5ServiceDelComboReq) (reply ManagementH5ServiceDelComboReply, err error) {
	err = a.xcli.Call(ctx, "ManagementH5ServiceDelCombo", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementH5ServiceSetComboFree(ctx context.Context, req *ManagementH5ServiceSetComboFreeReq) (reply ManagementH5ServiceSetComboFreeReply, err error) {
	err = a.xcli.Call(ctx, "ManagementH5ServiceSetComboFree", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementAddMerchantH5Service(ctx context.Context, req *ManagementAddMerchantH5ServiceReq) (reply ManagementAddMerchantH5ServiceReply, err error) {
	err = a.xcli.Call(ctx, "ManagementAddMerchantH5Service", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementGetMerchantH5Service(ctx context.Context, req *ManagementGetMerchantH5ServiceReq) (reply ManagementGetMerchantH5ServiceReply, err error) {
	err = a.xcli.Call(ctx, "ManagementGetMerchantH5Service", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementGetMerchantH5Combo(ctx context.Context, req *ManagementGetMerchantH5ComboReq) (reply ManagementGetMerchantH5ComboReply, err error) {
	err = a.xcli.Call(ctx, "ManagementGetMerchantH5Combo", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementSetMerchantH5Combo(ctx context.Context, req *ManagementSetMerchantH5ComboReq) (reply ManagementSetMerchantH5ComboReply, err error) {
	err = a.xcli.Call(ctx, "ManagementSetMerchantH5Combo", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementH5ApiGetBaseApiList(ctx context.Context, req *ManagementH5ApiGetBaseApiListReq) (reply ManagementH5ApiGetBaseApiListReply, err error) {
	err = a.xcli.Call(ctx, "ManagementH5ApiGetBaseApiList", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementGetUserMerchantName(ctx context.Context, req *ManagementGetUserMerchantNameReq) (reply ManagementGetUserMerchantNameReply, err error) {
	err = a.xcli.Call(ctx, "ManagementGetUserMerchantName", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementAddH5ThemeColor(ctx context.Context, req *ManagementAddH5ThemeColorReq) (reply ManagementAddH5ThemeColorReply, err error) {
	err = a.xcli.Call(ctx, "ManagementAddH5ThemeColor", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementDelH5ThemeColor(ctx context.Context, req *ManagementDelH5ThemeColorReq) (reply ManagementDelH5ThemeColorReply, err error) {
	err = a.xcli.Call(ctx, "ManagementDelH5ThemeColor", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementUpdateH5ThemeColor(ctx context.Context, req *ManagementUpdateH5ThemeColorReq) (reply ManagementUpdateH5ThemeColorReply, err error) {
	err = a.xcli.Call(ctx, "ManagementUpdateH5ThemeColor", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementGetH5ThemeColorList(ctx context.Context, req *ManagementGetH5ThemeColorListReq) (reply ManagementGetH5ThemeColorListReply, err error) {
	err = a.xcli.Call(ctx, "ManagementGetH5ThemeColorList", req, &reply)
	return
}

// order
func (a *GdManagementXClient) ManagementCreateDataApiOrder(ctx context.Context, req *ManagementCreateDataApiOrderReq) (reply ManagementCreateDataApiOrderReply, err error) {
	err = a.xcli.Call(ctx, "ManagementCreateDataApiOrder", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementCancelDataApiOrder(ctx context.Context, req *ManagementCancelDataApiOrderReq) (reply ManagementCancelDataApiOrderReply, err error) {
	err = a.xcli.Call(ctx, "ManagementCancelDataApiOrder", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementChangeDataApiOrderPrice(ctx context.Context, req *ManagementChangeDataApiOrderPriceReq) (reply ManagementChangeDataApiOrderPriceReply, err error) {
	err = a.xcli.Call(ctx, "ManagementChangeDataApiOrderPrice", req, &reply)
	return
}

func (a *GdManagementXClient) MangementGetDataApiOrderInfo(ctx context.Context, req *MangementGetDataApiOrderInfoReq) (reply MangementGetDataApiOrderInfoReply, err error) {
	err = a.xcli.Call(ctx, "MangementGetDataApiOrderInfo", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementGetDataApiOrderList(ctx context.Context, req *ManagementGetDataApiOrderListReq) (reply ManagementGetDataApiOrderListReply, err error) {
	err = a.xcli.Call(ctx, "ManagementGetDataApiOrderList", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementPayDataApiOrder(ctx context.Context, req *ManagementPayDataApiOrderReq) (reply ManagementPayDataApiOrderReply, err error) {
	err = a.xcli.Call(ctx, "ManagementPayDataApiOrder", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementCreateH5Order(ctx context.Context, req *ManagementCreateH5OrderReq) (reply ManagementCreateH5OrderReply, err error) {
	err = a.xcli.Call(ctx, "ManagementCreateH5Order", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementCancelH5Order(ctx context.Context, req *ManagementCancelH5OrderReq) (reply ManagementCancelH5OrderReply, err error) {
	err = a.xcli.Call(ctx, "ManagementCancelH5Order", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementChangeH5OrderPrice(ctx context.Context, req *ManagementChangeH5OrderPriceReq) (reply ManagementChangeH5OrderPriceReply, err error) {
	err = a.xcli.Call(ctx, "ManagementChangeH5OrderPrice", req, &reply)
	return
}

func (a *GdManagementXClient) MangementGetH5OrderInfo(ctx context.Context, req *MangementGetH5OrderInfoReq) (reply MangementGetH5OrderInfoReply, err error) {
	err = a.xcli.Call(ctx, "MangementGetH5OrderInfo", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementGetH5OrderList(ctx context.Context, req *ManagementGetH5OrderListReq) (reply ManagementGetH5OrderListReply, err error) {
	err = a.xcli.Call(ctx, "ManagementGetH5OrderList", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementPayH5Order(ctx context.Context, req *ManagementPayH5OrderReq) (reply ManagementPayH5OrderReply, err error) {
	err = a.xcli.Call(ctx, "ManagementPayH5Order", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementAddMerchantDataApiNew(ctx context.Context, req *ManagementCreateDataApiOrderReq) (reply ManagementCreateDataApiOrderReply, err error) {
	err = a.xcli.Call(ctx, "ManagementAddMerchantDataApiNew", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementAddMerchantH5ServiceNew(ctx context.Context, req *ManagementCreateH5OrderReq) (reply ManagementCreateH5OrderReply, err error) {
	err = a.xcli.Call(ctx, "ManagementGetH5ThemeColorList", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementGetUserMerchantListNew(ctx context.Context, req *ManagementGetUserMerchantListNewReq) (reply ManagementGetUserMerchantListNewReply, err error) {
	err = a.xcli.Call(ctx, "ManagementGetUserMerchantListNew", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementTryBaseApi(ctx context.Context, req *ManagementTryBaseApiReq) (reply ManagementTryBaseApiReply, err error) {
	err = a.xcli.Call(ctx, "ManagementTryBaseApi", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementGetTryApiTaskList(ctx context.Context, req *ManagementGetTryApiTaskListReq) (reply ManagementGetTryApiTaskListReply, err error) {
	err = a.xcli.Call(ctx, "ManagementGetTryApiTaskList", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementDeleteTryApiTask(ctx context.Context, req *ManagementDeleteTryApiTaskReq) (reply ManagementDeleteTryBaseApiTaskReply, err error) {
	err = a.xcli.Call(ctx, "ManagementDeleteTryApiTask", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementCreateTryApiTask(ctx context.Context, req *ManagementCreateTryApiTaskReq) (reply ManagementCreateTryApiTaskReply, err error) {
	err = a.xcli.Call(ctx, "ManagementCreateTryApiTask", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementUpdateTryApiTask(ctx context.Context, req *ManagementUpdateTryApiTaskReq) (reply ManagementUpdateTryApiTaskReply, err error) {
	err = a.xcli.Call(ctx, "ManagementUpdateTryApiTask", req, &reply)
	return
}
func (a *GdManagementXClient) ManagementBatchTryApi(ctx context.Context, req *ManagementBatchTryApiReq) (reply ManagementBatchTryApiReply, err error) {
	err = a.xcli.Call(ctx, "ManagementBatchTryApi", req, &reply)
	return
}

func (a *GdManagementXClient) ProviderBatchRequest(ctx context.Context, req *ProviderBatchRequestReq) (reply ProviderBatchRequestReply, err error) {
	err = a.xcli.Call(ctx, "ProviderBatchRequest", req, &reply)
	return
}
func (a *GdManagementXClient) TryApiTaskAdd(ctx context.Context, req *TryApiTaskAddReq) (reply TryApiTaskAddReply, err error) {
	err = a.xcli.Call(ctx, "TryApiTaskAdd", req, &reply)
	return
}

func (a *GdManagementXClient) TryApiTaskUpdate(ctx context.Context, req *TryApiTaskUpdateReq) (reply TryApiTaskUpdateReply, err error) {
	err = a.xcli.Call(ctx, "TryApiTaskUpdate", req, &reply)
	return
}

func (a *GdManagementXClient) GetTryApiTaskList(ctx context.Context, req *GetTryApiTaskListReq) (reply GetTryApiTaskListReply, err error) {
	err = a.xcli.Call(ctx, "GetTryApiTaskList", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementConvertMerchantDataApi(ctx context.Context, req *ManagementConvertMerchantDataApiReq) (reply ManagementConvertMerchantDataApiReply, err error) {
	err = a.xcli.Call(ctx, "ManagementConvertMerchantDataApi", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementSetBaseApiThreshold(ctx context.Context, req *ManagementSetBaseApiThresholdReq) (reply ManagementSetBaseApiThresholdReply, err error) {
	err = a.xcli.Call(ctx, "ManagementSetBaseApiThreshold", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementSetProviderThreshold(ctx context.Context, req *ManagementSetProviderThresholdReq) (reply ManagementSetProviderThresholdReply, err error) {
	err = a.xcli.Call(ctx, "ManagementSetProviderThreshold", req, &reply)
	return
}

func (a *GdManagementXClient) GetMerchantInfo(ctx context.Context, req *GetMerchantInfoReq) (reply GetMerchantInfoReply, err error) {
	err = a.xcli.Call(ctx, "GetMerchantInfo", req, &reply)
	return
}

func (a *GdManagementXClient) GetMerchantDataApiQuota(ctx context.Context, req *GetMerchantDataApiQuotaReq) (reply GetMerchantDataApiQuotaReply, err error) {
	err = a.xcli.Call(ctx, "GetMerchantDataApiQuota", req, &reply)
	return
}

func (a *GdManagementXClient) GetDataApiInfo(ctx context.Context, req *GetApiInfoReq) (reply GetApiInfoReply, err error) {
	err = a.xcli.Call(ctx, "GetDataApiInfo", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementDelMerchantDataApi(ctx context.Context, req *ManagementDelMerchantDataApiReq) (reply ManagementDelMerchantDataApiReply, err error) {
	err = a.xcli.Call(ctx, "ManagementDelMerchantDataApi", req, &reply)
	return
}
func (a *GdManagementXClient) ManagementGetMerchantBaseApiListAll(ctx context.Context, req *ManagementGetMerchantBaseApiListAllReq) (reply ManagementGetMerchantBaseApiListAllReply, err error) {
	err = a.xcli.Call(ctx, "ManagementGetMerchantBaseApiListAll", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementSetBaseApiShowInfo(ctx context.Context, req *ManagementSetBaseApiShowInfoReq) (reply ManagementSetBaseApiShowInfoReply, err error) {
	err = a.xcli.Call(ctx, "ManagementSetBaseApiShowInfo", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementSetDayCountLimit(ctx context.Context, req *ManagementSetDayCountLimitReq) (reply ManagementSetDayCountLimitReply, err error) {
	err = a.xcli.Call(ctx, "ManagementSetDayCountLimit", req, &reply)
	return
}

func (a *GdManagementXClient) UpdateMerchantDataApiQouta(ctx context.Context, req *UpdateMerchantDataApiReq) (reply UpdateMerchantDataApiReply, err error) {
	err = a.xcli.Call(ctx, "UpdateMerchantDataApiQouta", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementGetProviderMerchantApiList(ctx context.Context, req *ManagementGetProviderMerchantApiListReq) (reply ManagementGetProviderMerchantApiListReply, err error) {
	err = a.xcli.Call(ctx, "ManagementGetProviderMerchantApiList", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementGetApiTask(ctx context.Context, req *ManagementGetApiTaskReq) (reply ManagementGetApiTaskReply, err error) {
	err = a.xcli.Call(ctx, "ManagementGetApiTask", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementGetFilterRule(ctx context.Context, req *ManagementGetFilterRuleReq) (reply ManagementGetFilterRuleReply, err error) {
	err = a.xcli.Call(ctx, "ManagementGetFilterRule", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementUpdateDataSupplement(ctx context.Context, req *ManagementUpdateDataSupplementReq) (reply ManagementUpdateDataSupplementReply, err error) {
	err = a.xcli.Call(ctx, "ManagementUpdateDataSupplement", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementGetDataSupplement(ctx context.Context, req *ManagementGetDataSupplementReq) (reply ManagementGetDataSupplementReply, err error) {
	err = a.xcli.Call(ctx, "ManagementGetDataSupplement", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementGetSuplementTitle(ctx context.Context, req *ManagementGetSuplementTitleReq) (reply ManagementGetSuplementTitleReply, err error) {
	err = a.xcli.Call(ctx, "ManagementGetSuplementTitle", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementGetSupplementDb(ctx context.Context, req *ManagementGetSupplementDbReq) (reply ManagementGetSupplementDbReply, err error) {
	err = a.xcli.Call(ctx, "ManagementGetSupplementDb", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementGetBaseApiByRouter(ctx context.Context, req *ManagementGetBaseApiByRouterReq) (reply ManagementGetBaseApiByRouterReply, err error) {
	err = a.xcli.Call(ctx, "ManagementGetBaseApiByRouter", req, &reply)
	return
}

func (a *GdManagementXClient) GetProviderApiHystrix(ctx context.Context, req *GetProviderApiHystrixReq) (reply GetProviderApiHystrixReply, err error) {
	err = a.xcli.Call(ctx, "GetProviderApiHystrix", req, &reply)
	return
}

func (a *GdManagementXClient) UpdateProviderApiHystrix(ctx context.Context, req *UpdateProviderApiHystrixReq) (reply UpdateProviderApiHystrixReply, err error) {
	err = a.xcli.Call(ctx, "UpdateProviderApiHystrix", req, &reply)
	return
}

func (a *GdManagementXClient) UpdateMerchantDataApiAlias(ctx context.Context, req *UpdateMerchantDataApiAliasReq) (reply UpdateMerchantDataApiAliasReply, err error) {
	err = a.xcli.Call(ctx, "UpdateMerchantDataApiAlias", req, &reply)
	return
}

func (a *GdManagementXClient) BillList(ctx context.Context, req *BillListReq) (reply BillListReply, err error) {
	err = a.xcli.Call(ctx, "BillList", req, &reply)
	return
}

func (a *GdManagementXClient) ChargeList(ctx context.Context, req *ChargeListReq) (reply ChargeListReply, err error) {
	err = a.xcli.Call(ctx, "ChargeList", req, &reply)
	return
}

func (a *GdManagementXClient) ConsumeList(ctx context.Context, req *ConsumeListReq) (reply ConsumeListReply, err error) {
	err = a.xcli.Call(ctx, "ConsumeList", req, &reply)
	return
}

func (a *GdManagementXClient) ConsumeTrendList(ctx context.Context, req *ConsumeTrendListReq) (reply ConsumeTrendListReply, err error) {
	err = a.xcli.Call(ctx, "ConsumeTrendList", req, &reply)
	return
}

func (a *GdManagementXClient) MerchantCharge(ctx context.Context, req *MerchantChargeReq) (reply MerchantChargeReply, err error) {
	err = a.xcli.Call(ctx, "MerchantCharge", req, &reply)
	return
}

func (a *GdManagementXClient) MerchantDataApiPriceList(ctx context.Context, req *MerchantDataApiPriceListReq) (reply MerchantDataApiPriceListReply, err error) {
	err = a.xcli.Call(ctx, "MerchantDataApiPriceList", req, &reply)
	return
}

func (a *GdManagementXClient) MerchantPriceList(ctx context.Context, req *MerchantPriceListReq) (reply MerchantPriceListReply, err error) {
	err = a.xcli.Call(ctx, "MerchantPriceList", req, &reply)
	return
}

func (a *GdManagementXClient) SetMerchantDataApiPrice(ctx context.Context, req *SetMerchantDataApiPriceReq) (reply SetMerchantDataApiPriceReply, err error) {
	err = a.xcli.Call(ctx, "SetMerchantDataApiPrice", req, &reply)
	return
}

func (a *GdManagementXClient) SetMerchantType(ctx context.Context, req *SetMerchantTypeReq) (reply SetMerchantTypeReply, err error) {
	err = a.xcli.Call(ctx, "SetMerchantType", req, &reply)
	return
}

func (a *GdManagementXClient) BillDetailList(ctx context.Context, req *BillDetailListReq) (reply BillDetailListReply, err error) {
	err = a.xcli.Call(ctx, "BillDetailList", req, &reply)
	return
}

func (a *GdManagementXClient) UpdateBillDetail(ctx context.Context, req *UpdateBillDetailReq) (reply UpdateBillDetailReply, err error) {
	err = a.xcli.Call(ctx, "UpdateBillDetail", req, &reply)
	return
}

func (a *GdManagementXClient) BillRemark(ctx context.Context, req *BillRemarkReq) (reply BillRemarkReply, err error) {
	err = a.xcli.Call(ctx, "BillRemark", req, &reply)
	return
}

func (a *GdManagementXClient) ManagementGetUserMerchantAuthList(ctx context.Context, req *ManagementGetUserMerchantAuthListNewReq) (reply ManagementGetUserMerchantAuthListNewReply, err error) {
	err = a.xcli.Call(ctx, "ManagementGetUserMerchantAuthList", req, &reply)
	return
}

func (a *GdManagementXClient) GenerateBill(ctx context.Context, req *GenerateBillReq) (reply GenerateBillReply, err error) {
	err = a.xcli.Call(ctx, "GenerateBill", req, &reply)
	return
}

func (a *GdManagementXClient) BillExportExcel(ctx context.Context, req *BillExportExcelReq) (reply BillExportExcelReply, err error) {
	err = a.xcli.Call(ctx, "BillExportExcel", req, &reply)
	return
}
