package gd_vehicle

// 获取车款
type VehicleGetStyleReq struct {
	Vin       string `json:"vin" description:"vin码，车辆唯一标识"`
	PlateNo   string `json:"plate_no" description:"车牌号码"`
	PlateType string `json:"plate_type" description:"车牌种类"`
	AppKey    string `json:"app_key" description:"数据智能平台appkey"`
}
type VehicleStyleInfo struct {
	UtStyleName string `json:"ut_style_name" description:"车型"`
	UtStyleId   int64  `json:"ut_style_id" description:"小时代车型唯一id"`
}
type VehicleGetStyleReply struct {
	VehicleStyles []VehicleStyleInfo `json:"vehicle_styles" description:"车型"`
}

// 获取车辆信息
type VehicleGetInfoReq struct {
	PlateNo   string `json:"plate_no" description:"车牌号码"`
	Vin       string `json:"vin" description:"vin码，车辆唯一标识"`
	PlateType string `json:"plate_type" description:"车牌种类"`
	//UtStyleId int64  `json:"ut_style_id" description:"小时代车型唯一id"`
	AppKey string `json:"app_key" description:"数据智能平台appkey"`
}

type VehicleAge struct {
	YearCount  int64 `json:"yearCount"`  //年
	MonthCount int64 `json:"monthCount"` //月
}

type VehicleGetInfoReply struct {
	UseProperty             string     `json:"use_property" description:"使用性质"`
	PlateType               string     `json:"plate_type" description:"号牌种类"`
	BrandId                 int64      `json:"brand_id" description:"车辆品牌id"`
	BrandName               string     `json:"brand_name" description:"车辆品牌"`
	MakerType               string     `json:"maker_type" description:"厂商类型"`
	SeriesName              string     `json:"series_name" description:"车系"`
	Price                   string     `json:"price" description:"指导价"`
	VehicleAge              VehicleAge `json:"vehicle_age" description:"车龄"`
	VehicleAgeDesc          string     `json:"vehicle_age_desc" description:"车龄描述"`
	SeatNumber              int64      `json:"seat_number" description:"座位数"`
	DischargeStandard       string     `json:"discharge_standard" description:"排放标准"`
	FuelType                string     `json:"fuel_type" description:"车辆燃油类型"`
	EngineNo                string     `json:"engine_no" description:"发动机号"`
	Vin                     string     `json:"vin" description:"vin码，车辆唯一标识"`
	InitialRegistrationDate string     `json:"initial_registration_date" description:"初次登记日期"`
	VehicleType             string     `json:"vehicle_type" description:"车辆类型"`
}

type VehicleGetConfigurationReq struct {
	/*PlateNo string `json:"plate_no" description:"车牌号码" required:"true" in:"query"`
	Vin     string `json:"vin" description:"车辆识别码" required:"true" in:"query"`*/
	UtStyleId int64  `json:"ut_style_id" description:"车款id"`
	AppKey    string `json:"app_key" description:"appkey" required:"true" in:"query"`
}

type VehicleGetConfigurationReply struct {
	Attribute       TGdVehicleModelAttribute   `json:"attribute" description:"属性表信息"`
	Basic           TGdVehicleBasic            `json:"basic" description:"车辆基本信息"`
	Body            TGdVehicleBody             `json:"body" description:"车身信息"`
	Business        TGdBusinessInfo            `json:"business" description:"业务信息"`
	CrossCountry    TGdCrossCountryPerformance `json:"cross_country" description:"越野性能"`
	OilInfo         TGdOilInfo                 `json:"oil" description:"油耗信息"`
	EngineInfo      TGdEngineInfo              `json:"engine" description:"发动机信息"`
	ElectricInfo    TGdElectricInfo            `json:"electric" description:"电动机信息"`
	GearboxInfo     TGdGearboxInfo             `json:"gearbox" description:"变速箱信息"`
	ChassisInfo     TGdChassisInfo             `json:"chassis" description:"底盘信息"`
	WheelBrake      TGdWheelBrake              `json:"wheelbrake" description:"轮胎制动信息"`
	SafetyEquipment TGdSafetyEquipment         `json:"safety" description:"安全装备信息"`
	FunctionInfo    TGdFunctionInfo            `json:"function_config" description:"功能配置信息"`
	SeatInfo        TGdSeatInfo                `json:"seat" description:"座椅信息"`
	MediaInfo       TGdMediaInfo               `json:"media" description:"多媒体信息"`
	LightInfo       TGdLightInfo               `json:"light" description:"车灯信息"`
	RearviewWindow  TGdRearviewWindow          `json:"rearview_window" description:"车窗及后视镜"`
	Aircondition    TGdAirconditionInfo        `json:"aircondition" description:"空调和冰箱"`
}

type TGdVehicleModelAttribute struct {
	Id                int64   `json:"-" description:""`
	UtStyleId         int64   `json:"-" description:"车款id"`
	DischargeStandard string  `json:"discharge_standard" description:""`
	SeriesGroupName   string  `json:"series_group_name" description:"中文品牌"`
	SeriesName        string  `json:"series_name" description:"品牌名称"`
	ModelYear         string  `json:"model_year" description:"车型年份"`
	BrandId           string  `json:"brand_id" description:"品牌ID"`
	GearType          string  `json:"gear_type" description:""`
	Liter             string  `json:"liter" description:""`
	UtStyleName       string  `json:"ut_style_name" description:"车型名称"`
	BrandName         string  `json:"brand_name" description:"品牌名称"`
	SeriesId          int64   `json:"series_id" description:""`
	Price             float64 `json:"price" description:"车型价格"`
	MinRegYear        int64   `json:"min_reg_year" description:""`
	MaxRegYear        int64   `json:"max_reg_year" description:""`
	MakerType         string  `json:"maker_type" description:"制造类型"`
	SeatNumber        int     `json:"seat_number" description:"座位数"`
	UpdateTime        int64   `json:"update_time" description:"更新时间"`
	CreateTime        int64   `json:"create_time" description:"创建时间"`
	OilNumber         string  `json:"oil_number" description:"油号"`
	OilLable          string  `json:"oil_lable" description:"油标"`
	ExtendedWarranty  string  `json:"extended_warranty" description:""`
}

type TGdVehicleBasic struct {
	Id            int64  `json:"-" description:""`
	UtStyleId     int64  `json:"-" description:"车款id"`
	VehicleBrand  string `json:"vehicle_brand" description:"车辆品牌"`
	VehicleFirm   string `json:"vehicle_firm" description:"车辆厂商"`
	VehicleSeries string `json:"vehicle_series" description:"车系"`
	VehicleModel  string `json:"vehicle_model" description:"车型"`
	//	VehicleStyle      string `json:"" description:""`
	Level             string `json:"" description:"级别"`
	VehicleStructure  string `json:"vehicle_structure" description:"车体结构"`
	LWH               string `json:"L_W_H" description:"长宽高" orm:"column(L_W_H)"`
	Engine            string `json:"engine" description:"发动机"`
	Gearbox           string `json:"gearbox" description:"变速箱"`
	StimulusType      string `json:"stimulus_type" description:"动力类型"`
	MaximumSpeed      string `json:"maximum_speed" description:"官方最高车速"`
	HundredAccelerate string `json:"hundred_accelerate" description:"官方0-100加速"`
	VehicleCompany    string `json:"vehicle_company" description:"生产企业"`
	VehicleType       string `json:"vehicle_type" description:"车辆种类"`
	VehicleName       string `json:"vehicle_name" description:"通用名称"`
	VehicleWarranty   string `json:"vehicle_warranty" description:"质保"`
}

type TGdVehicleBody struct {
	Id                 int64  `json:"-" description:""`
	UtStyleId          int64  `json:"-" description:""`
	Length             string `json:"length" description:"车身长"`
	Width              string `json:"width" description:"车身宽"`
	Height             string `json:"height" description:"车身高"`
	ContainerLength    string `json:"container_length" description:"货箱长"`
	ContainerWidth     string `json:"container_width" description:"货箱宽"`
	ContainerHeight    string `json:"container_height" description:"货箱高"`
	AxleNumber         string `json:"axle_number" description:"轴数"`
	Wheelbase          string `json:"wheelbase" description:"轴距"`
	AxleWeight         string `json:"axle_weight" description:"轴荷"`
	WheelNumber        string `json:"wheel_number" description:"轮胎数"`
	FrontWheelDistance string `json:"front_wheel_distance" description:"前轮距"`
	BackWheelDistance  string `json:"back_wheel_distance" description:"后轮距"`
	GrossMass          string `json:"gross_mass" description:"总质量"`
	UnladenMass        string `json:"unladen_mass" description:"整备质量"`
	ApprovedLoad       string `json:"aprrove_load" description:"最大载重质量"`
	BodyStructure      string `json:"body_structure" description:"车身结构"`
	BodyMaterial       string `json:"body_material" description:"车身材质"`
	BodyColour         string `json:"body_colour" description:"车身颜色"`
	DoorNumber         string `json:"door_number" description:"车门数"`
	DoorOpenmode       string `json:"door_openmode" description:"开门方式"`
	BackdoorOpenmode   string `json:"backdoor_openmode" description:"后排车门开启方式"`
	SeatNumber         string `json:"seat_number" description:"座位数"`
	OilboxVolume       string `json:"oilbox_volume" description:"油箱容积"`
	SecondOilboxVolume string `json:"second_oilbox_volume" description:"第二油箱容积"`
	TrunkVolume        string `json:"trunk_volume" description:"行李箱容积"`
	TrunkEosd          string `json:"trunk_EOSD" description:"行李箱电动吸合门" orm:"column(trunk_EOSD)"`
	TrunkOpenmode      string `json:"trunk_openmode" description:"行李箱打开方式"`
	TrunklidOpenmode   string `json:"trunklid_openmode" description:"行李箱盖开合方式"`
	TrunkInternalSize  string `json:"trunk_internal_size" description:"后备箱内部尺寸mm"`
	ContainerSize      string `json:"container_size" description:"货箱尺寸mm"`
}

type TGdBusinessInfo struct {
	Id                int64  `json:"-" description:""`
	UtStyleId         int64  `json:"-" description:""`
	MaintainPeriod    string `json:"maintain_period" description:"保养周期"`
	MaintainCost      string `json:"maintain_cost" description:"保养费用"`
	MaintainPolicy    string `json:"maintain_policy" description:"保养政策"`
	Msrp              string `json:"MSRP" description:"厂商指导价" orm:"column(MSRP)"`
	FsShopLowestOffer string `json:"fs_shop_lowest_offer" description:"4s店最低报价"`
}

type TGdCrossCountryPerformance struct {
	Id                           int64  `json:"-" description:""`
	UtStyleId                    int64  `json:"-" description:""`
	MinimumGroundClearance       string `json:"minimum_ground_clearance" description:"最小离地间隙"`
	MinimumTurnRadius            string `json:"minimum_turn_radius" description:"最小转弯半径"`
	ApproachAngle                string `json:"approach_angle" description:"接近角"`
	DepartureAngle               string `json:"departure_angle" description:"离去角"`
	MaximumFordingDepth          string `json:"maximum_fording_depth" description:"最大涉水深度"`
	MaximumGradientClimbingAngle string `json:"maximum_gradient_climbingAngle" description:"最大爬坡"`
	RampAngle                    string `json:"ramp_angle" description:"纵向通过角"`
}

type TGdOilInfo struct {
	Id                   int64  `json:"-" description:""`
	UtStyleId            int64  `json:"-" description:""`
	OilWearComprehensive string `json:"oil_wear_comrehensive" description:"综合部油耗综合工况"`
	OilWearUrban         string `json:"oil_wear_urban" description:"综合部油耗市区工况"`
	OilWearSuburbs       string `json:"oil_wear_suburbs" description:"综合部油耗市郊工况"`
}

type TGdEngineInfo struct {
	Id                   int64  `json:"-" description:""`
	UtStyleId            int64  `json:"-" description:""`
	EngineNumber         string `json:"engine_number" description:"发动机型号"`
	EngineDetail         string `json:"engine_detail" description:"发动机描述"`
	EngineType           string `json:"engine_type" description:"发动机类型"`
	EngineCompany        string `json:"engine_company" description:"发动机生产企业"`
	EngineTechnology     string `json:"engine_technology" description:"发动机特有技术"`
	EnginePosition       string `json:"engine_position" description:"发动机位置"`
	PistonStroke         string `json:"piston_stroke" description:"发动机活塞行程"`
	FuelType             string `json:"fuel_type" description:"燃料种类"`
	FuelLable            string `json:"fuel_lable" description:"燃油标号"`
	EffluentStandard     string `json:"effluent_standard" description:"排放标准"`
	OilSupplyMode        string `json:"oil_supply_mode" description:"供油方式"`
	Displacement_L       string `json:"displacement_L" description:"排量L" orm:"column(displacement_L)"`
	Displacement_ML      string `json:"displacement_mL" description:"排量ML" orm:"column(displacement_mL)"`
	CylinderHeadMaterial string `json:"cylinder_head_material" description:"缸盖材料"`
	CylinderMaterial     string `json:"cylinder_material" description:"缸体材料"`
	CylinderDiameter     string `json:"cylinder_diameter" description:"缸径mm"`
	CylinderNumber       string `json:"cylinder_number" description:"气缸数"`
	CylinderVolume       string `json:"cylinder_volume" description:"气缸容积"`
	IntakeForm           string `json:"intake_form" description:"进气形式"`
	CylinderArrangement  string `json:"cylinder_arrangement" description:"气缸排列形式"`
	CylinderValveNumber  string `json:"cylinder_valve_number" description:"每缸气门数"`
	ValveStructure       string `json:"valve_structure" description:"气门结构"`
	ValveMechanism       string `json:"valve_mechanism" description:"配气机构"`
	ReductionRatio       string `json:"reduction_ratio" description:"压缩比"`
	MaximumHorsepower    string `json:"maximum_horsepower" description:"最大马力"`
	MaximumTorqueRpm     string `json:"maximum_torque_rpm" description:"最大扭矩(N*m/rpm)"`
	Rpm                  string `json:"rpm" description:"最大扭矩转速"`
	MaximumTorque        string `json:"maximum_torque" description:"最大扭矩(N*m)"`
	MaximumPowerRpm      string `json:"maximum_power_rpm" description:"最大功率转速(kw/rpm)"`
	RatedPower           string `json:"rated_power" description:"额定功率"`
	Power_L              string `json:"power_L" description:"升功率" orm:"column(power_l)"`
	MixedType            string `json:"mixed_type" description:"混合类型"`
	PlugForm             string `json:"plug_form" description:"插电形式"`
	MaximumPower         string `json:"maximum_power" description:"最大功率"`
}

type TGdElectricInfo struct {
	Id                             int64  `json:"-" description:""`
	UtStyleId                      int64  `json:"-" description:""`
	ElectricMaximumPower           string `json:"electric_maximum_power" description:"电动机最大功率"`
	ElectricTorque                 string `json:"electric_torque" description:"电动机最大扭矩"`
	MaximumSimulationMileage       string `json:"maximum_simulation_milage" description:"最大行驶里程"`
	MaximumBatteryEnduranceMileage string `json:"maximum_battery_endurance_mileage" description:"电池支持最高续航里程"`
	BatteryType                    string `json:"battery_type" description:"电池种类"`
	BatteryCapacity                string `json:"battery_capacity" description:"电池容量"`
	MotorNumber                    string `json:"motor_number" description:"电机数"`
	ChargingCapability             string `json:"charging_capability" description:"充电兼容性"`
	ChargingType                   string `json:"charging_type" description:"充电方式"`
	FastChargingTime               string `json:"fast_charging_time" description:"快充时间"`
	SlowChargingTime               string `json:"slow_charging_time" description:"慢充时间"`
}

type TGdGearboxInfo struct {
	Id          int64  `json:"-" description:""`
	UtStyleId   int64  `json:"-" description:""`
	Gearbox     string `json:"gearbox" description:"变速箱简称"`
	GearboxType string `json:"gearbox_type" description:"变速箱类型"`
	GearNumber  string `json:"gear_number" description:"档位个数"`
	GearPaddles string `json:"gear_paddles" description:"换挡拨片"`
}

type TGdChassisInfo struct {
	Id                           int64  `json:"-" description:""`
	UtStyleId                    int64  `json:"-" description:""`
	DriveType                    string `json:"drive_type" description:"驱动方式"`
	FrontSuspentionType          string `json:"front_suspention_type" description:"前悬挂类型"`
	BackSuspentionType           string `json:"back_suspention_type" description:"后悬挂类型"`
	ChassisStructure             string `json:"chassis_structure" description:"底盘结构"`
	FourWheelType                string `json:"four_wheel_type" description:"四驱形式"`
	CentralDifferentialStructure string `json:"central_differential_structure" description:"中央差速器结构"`
	CentralDifferentialLock      string `json:"central_differential_lock" description:"中央差速器锁止功能"`
	AdjustableSuspention         string `json:"adjustable_suspention" description:"可调悬挂"`
	AirSuspention                string `json:"air_suspention" description:"空气悬挂"`
	SteeringPower                string `json:"steering_power" description:"转向助力"`
	FourWheelConversionType      string `json:"four_wheel_conversion_type" description:"四驱转换方式"`
	AssistType                   string `json:"assist_type" description:"助力类型"`
}

type TGdWheelBrake struct {
	Id                           int64  `json:"-" description:""`
	UtStyleId                    int64  `json:"-" description:""`
	FrontWheelSpecification      string `json:"front_wheel_specification" description:"前轮胎规格"`
	FrontWheelBossSpecification  string `json:"front_wheel_boss_specification" description:"前轮毂规格"`
	BackWheelSpecification       string `json:"back_wheel_specification" description:"后轮胎规格"`
	BackWheelBossSpecification   string `json:"back_wheel_boss_specification" description:"后轮毂规格"`
	WheelBossMateria             string `json:"wheel_boss_materia" description:"轮毂材料"`
	SpareWheelSpecification      string `json:"spare_wheel_specification" description:"备胎规格"`
	SecondSpareWheel             string `json:"second_spare_wheel" description:"第二备胎"`
	SpareWheelSize               string `json:"spare_wheel_size" description:"备胎尺寸"`
	FrontBrakeType               string `json:"front_brake_type" description:"前制动类型"`
	BackBrakeType                string `json:"back_brake_type" description:"后制动类型"`
	ParkingBrakeType             string `json:"parking_brake_type" description:"驻车制动类型"`
	SplitterType                 string `json:"splitter_type" description:"分动器类型"`
	FrontLimitedSlipDifferential string `json:"front_limited_slip_differential" description:"前桥限滑差速器"`
	BackLimitedSlipDifferential  string `json:"back_limited_slip_differential" description:"后桥限滑差速器"`
}

type TGdSafetyEquipment struct {
	Id                          int64  `json:"-" description:""`
	UtStyleId                   int64  `json:"-" description:""`
	MainSeatAirbag              string `json:"main_seat_airbag" description:"主驾驶安全气囊"`
	AuxiliarySeatAirbag         string `json:"auxiliary_seat_airbag" description:"副驾驶安全气囊"`
	FrontSideAirbag             string `json:"front_side_airbag" description:"前排侧气囊"`
	BackSideAirbag              string `json:"back_side_airbag" description:"后排侧气囊"`
	FrontHeadAirbag             string `json:"front_head_airbag" description:"前头部气帘"`
	BackHeadAirbag              string `json:"back_head_airbag" description:"后头部气帘"`
	KneeAirbag                  string `json:"knee_airbag" description:"膝部气囊"`
	SeatbeltWarning             string `json:"seat_belt_warning" description:"安全带未系提示"`
	AutoAntiLock                string `json:"auto_anti_lock" description:"自动防抱死"`
	BrakeDistribution           string `json:"brake_distribution" description:"制动力分配"`
	AuxiliaryBrake              string `json:"auxiliary_brake" description:"刹车辅助"`
	TractionControl             string `json:"traction_control" description:"牵引力控制"`
	VehicleBodyStabilityControl string `json:"vehicle_body_stability_control" description:"车身稳定控制"`
	ActiveBrake                 string `json:"active_brake" description:"主动刹车"`
	AutoParking                 string `json:"auto_parking" description:"自动驻车"`
	HillStartAssist             string `json:"hill_start_assist" description:"上坡辅助"`
	HillDecent                  string `json:"hill_decent" description:"陡坡缓降"`
	ElectronicAntiTheft         string `json:"electronic_anti_theft" description:"发动机电子防盗"`
	CentralControlLock          string `json:"central_control_lock" description:"车内中控锁"`
	RemoteKey                   string `json:"remote_key" description:"遥控钥匙"`
	KeylessStartSystem          string `json:"keyless_start_system" description:"无钥匙启动系统"`
	KeylessEntrySystem          string `json:"keyless_entry_system" description:"无钥匙进入系统"`
	TirePresureMonitor          string `json:"tire_presure_monitor" description:"胎压监测装置"`
	ZeroTirePresureDrive        string `json:"zero_tire_presure_drive" description:"零胎压继续行驶"`
	ParallelAuxiliary           string `json:"parallel_auxiliary" description:"并线辅助"`
	ViewCamara                  string `json:"view_camara" description:"全景摄像头"`
	NightVision                 string `json:"night_vision" description:"夜视系统"`
	ISO_FIX                     string `json:"ISO_FIX" description:"ISO FIX儿童座椅接口" orm:"column(ISO_FIX)"`
	LATCH                       string `json:"LATCH" description:"LATCH座椅接口" orm:"column(LATCH)"`
	ChildSafetyLock             string `json:"child_safety_lock" description:"儿童安全锁"`
	FrontBeltAdjustment         string `json:"front_belt_adjustment" description:"前安全带调节"`
	FatigueDrivingWarning       string `json:"fatigue_driving_warning" description:"疲劳驾驶提示"`
	ThirdAirbag                 string `json:"third_airbag" description:"第三排头部气囊"`
	ThreePointBelt              string `json:"three_point_belt" description:"后排中间三点式安全带"`
	BeltPreTightening           string `json:"belt_pre_tightening" description:"安全带预收紧"`
	BackBeltAirbag              string `json:"back_belt_airbag" description:"后排安全带气囊"`
	BeltRestraint               string `json:"belt_restraint" description:"安全带限力"`
	ExplosionProofTire          string `json:"explosion_proof_tire" description:"防爆轮胎"`
}

type TGdFunctionInfo struct {
	Id                              int64  `json:"-" description:""`
	UtStyleId                       int64  `json:"-" description:""`
	SkylightType                    string `json:"skylight_type" description:"天窗形式"`
	SportsAppearanceKit             string `json:"sports_appearance_kit" description:"运动外观套件"`
	EOSD                            string `json:"EOSD" description:"电动吸合门" orm:"column(EOSD)"`
	ElectricTrunk                   string `json:"electric_trunk" description:"电动后备箱"`
	InductiveTrunk                  string `json:"inductive_trunk" description:"感应后背箱"`
	RoofLuggageRack                 string `json:"roof_luggage_rack" description:"车顶行李架"`
	LeatherSteeringWheel            string `json:"leather_steering_wheel" description:"真皮方向盘"`
	SteeringWheelAdjustment         string `json:"steering_wheel_adjustment" description:"方向盘调节"`
	SteeringWheelElectricAdjustment string `json:"steering_wheel_electric_adjustment" description:"方向盘电动调节"`
	MultifunctionalSteeringWheel    string `json:"multi_functional_steering_wheel" description:"多功能方向盘"`
	SteeringWheelShift              string `json:"steering_wheel_shift" description:"方向盘换挡"`
	SteeringWheelHeating            string `json:"steering_wheel_heating" description:"方向盘加热"`
	SteeringWheelRemember           string `json:"steering_wheel_remember" description:"方向盘记忆"`
	FullLCDDashboard                string `json:"full_LCD_dashboard" description:"全液晶仪表盘" orm:"column(full_LCD_dashboard)"`
	FixedSpeedCruiseControl         string `json:"fixed_speed_cruise_control" description:"定速巡航"`
	AdaptiveCruiseControl           string `json:"adaptive_cruise_control" description:"自适应巡航"`
	DrivingComputerDisplay          string `json:"driving_computer_display" description:"行车电脑显示屏"`
	HUDRisingNumberDisplay          string `json:"HUD_rising_number_display" description:"HUD抬头数字显示" orm:"column(HUD_rising_number_display)"`
	ReversingRador                  string `json:"reversing_rador" description:"倒车雷达"`
	ReversingImage                  string `json:"reversing_image" description:"倒车影像"`
	AutomaticParkingEntry           string `json:"automatic_parking_entry" description:"自动停车入位"`
	LuggageCompartmentLamp          string `json:"luggage_compartment_lamp" description:"行李舱灯"`
	IndependentPowerInterface       string `json:"independent_power_interface" description:"独立电源接口"`
	CentralLCDSplitScreen           string `json:"central_LCD_split_screen" description:"中控液晶屏分屏显示" orm:"column(central_LCD_split_screen)"`
	FrontParkingRador               string `json:"front_parking_rador" description:"前驻车雷达"`
	BackParkingRador                string `json:"back_parking_rador" description:"后驻车雷达"`
	ElectricSkylight                string `json:"electric_skylight" description:"电动天窗"`
	PanoramicSkylight               string `json:"panoramic_skylight" description:"全景天窗"`
}

type TGdSeatInfo struct {
	Id                        int64  `json:"-" description:""`
	UtStyleId                 int64  `json:"-" description:""`
	SeatMaterial              string `json:"seat_material" description:"座椅材质"`
	SportSeat                 string `json:"sport_seat" description:"运动座椅"`
	HighLowAdjust             string `json:"high_low_adjust" description:"座椅高低调节"`
	WaistSupportAdjust        string `json:"waist_support_adjust" description:"腰部支撑调节"`
	ShoulderSupportAdjust     string `json:"shoulder_support_adust" description:"肩部支撑调节"`
	AuxiliaryElectricAdjust   string `json:"auxiliary_electric_adjust" description:"副驾驶座电动调节"`
	MainElectricAdjust        string `json:"main_electric_adust" description:"主驾驶座电动调节"`
	ElectricSeatRemeber       string `json:"electric_seat_remeber" description:"电动座椅记忆"`
	FrontHeating              string `json:"front_heating" description:"前座椅加热"`
	BackHeating               string `json:"back_heating" description:"后座椅加热"`
	FrontAeration             string `json:"front_aeration" description:"前座椅通风"`
	BackAeration              string `json:"back_aeration" description:"后座椅通风"`
	FrontMassage              string `json:"front_massage" description:"前座椅按摩"`
	BackMassage               string `json:"back_massage" description:"后座椅按摩"`
	BackDownType              string `json:"back_down_type" description:"后排座椅倒放方式"`
	Third                     string `json:"third" description:"第三排座椅"`
	FrontHandrail             string `json:"front_handrail" description:"前座中央扶手"`
	BackHandrail              string `json:"back_handrail" description:"后座中央扶手"`
	BackCupHolder             string `json:"back_cup_holder" description:"后排杯架"`
	SecondMove                string `json:"second_move" description:"第二排座椅移动"`
	BackLegRest               string `json:"back_leg_rest" description:"后排腿托"`
	HeatingCoolingCupHolder   string `json:"heating_cooling_cup_holder" description:"可加热制冷杯架" orm:"column(HCCH)"`
	SecondThirdRemove         string `json:"second_third_remove" description:"第二三排座椅可拆"`
	BackFoldTable             string `json:"back_fold_table" description:"后排折叠桌板"`
	SecondIndependent         string `json:"second_independent" description:"第二排独立座椅"`
	AuxiliaryAdjustableButton string `json:"auxiliary_adjustable_button" description:"副驾驶位后排可调节按钮"`
	SecondBackrestAdjust      string `json:"second_backrest_adjust" description:"第二排靠背角度调节"`
}

type TGdMediaInfo struct {
	Id                     int64  `json:"-" description:""`
	UtStyleId              int64  `json:"-" description:""`
	CdDvd                  string `json:"CD_DVD" description:"CD/DVD"`
	Mp3Wma                 string `json:"CD_MP3_WMA" description:"CD支持MP3/WMA"`
	ExternalAudioInterface string `json:"external_audio_interface" description:"外接音源接口"`
	SpeakerNumber          string `json:"speaker_number" description:"扬声器个数"`
	AudioBrand             string `json:"audio_brand" description:"音响品牌"`
	CarPhone               string `json:"car_phone" description:"车载电话"`
	CarTv                  string `json:"car_tv" description:"车载电视"`
	CentralLcd             string `json:"cantral_LCD" description:"中控台液晶屏"`
	BackLcd                string `json:"back_LCD" description:"后排液晶屏"`
	Gps                    string `json:"gps" description:"GPS导航系统"`
	CarTelematics          string `json:"car_telematics" description:"车载信息服务"`
	ManMachine             string `json:"man_machine" description:"人机交互系统"`
	PositionService        string `json:"position_service" description:"定位互动服务"`
	CentralColourScreen    string `json:"central_colour_screen" description:"中控台彩色大屏"`
	MultimediaSystem       string `json:"multimedia_system" description:"多媒体系统"`
	InternalHarddisk       string `json:"internal_harddisk" description:"内置硬盘"`
}

type TGdLightInfo struct {
	Id                int64  `json:"-" description:""`
	UtStyleId         int64  `json:"-" description:""`
	Near              string `json:"near" description:"近光灯"`
	Far               string `json:"far" description:"远光灯"`
	Daytime           string `json:"daytime" description:"日间行车灯"`
	Fog               string `json:"fog" description:"前雾灯"`
	AutoOpenClose     string `json:"auto_open_close" description:"大灯自动开闭"`
	AutoAdjust        string `json:"auto_ajust" description:"大灯随动调节"`
	HeightAdjustable  string `json:"height_adjustable" description:"大灯高度可调"`
	Clean             string `json:"clean" description:"大灯清洗装置"`
	Atmosphere        string `json:"atmosphere" description:"车内氛围灯"`
	AdaptiveFarNear   string `json:"adaptive_far_near" description:"自适应远近光"`
	SteeringAuxiliary string `json:"steering_auxiliary" description:"转向辅助"`
	Luggage           string `json:"luggage" description:"行李箱灯"`
	Read              string `json:"read" description:"车前阅读灯"`
	SideTurn          string `json:"side_turn" description:"侧转向灯"`
	AutoHead          string `json:"auto_head" description:"自动头灯"`
	Led               string `json:"led" description:"LED大灯"`
	LedTail           string `json:"led_tail" description:"LED尾灯"`
	HighBrake         string `json:"high_brake" description:"高位制动灯"`
	Helium            string `json:"helium" description:"氙气大灯"`
}

type TGdRearviewWindow struct {
	Id                     int64  `json:"-" description:""`
	UtStyleId              int64  `json:"-" description:""`
	FrontElectricWindow    string `json:"front_electric_window" description:"前电动车窗"`
	BackElectricWindow     string `json:"back_electric_window" description:"后电动车窗"`
	WindowOneKey           string `json:"window_one_key" description:"车窗一键功能"`
	AntiPinchHand          string `json:"anti_pinch_hand" description:"车窗防夹手"`
	HeatProtection         string `json:"heat_protection" description:"隔热玻璃"`
	OutDizzy               string `json:"out_dizzy" description:"外后视镜防眩晕"`
	InDizzy                string `json:"in_zizzy" description:"内后视镜防眩晕"`
	RearviewElectricAdjust string `json:"rearview_electric_adjust" description:"后视镜电动调节"`
	RearviewHeat           string `json:"rearview_heat" description:"后视镜加热"`
	RearviewElectricFold   string `json:"rearview_electric_fold" description:"后视镜电动折叠"`
	FrontWiper             string `json:"front_wiper" description:"前感应雨刷"`
	BackWiper              string `json:"back_wiper" description:"后雨刷"`
	BackCleanFrost         string `json:"back_clean_frost" description:"后风挡除霜"`
	BackSunshade           string `json:"back_sunshade" description:"后风挡遮阳帘"`
	BackSideSunshade       string `json:"back_side_sunshade" description:"后排侧遮阳帘"`
	BackSidePrivacy        string `json:"back_side_privacy" description:"后排侧隐私玻璃"`
	RearviewRemember       string `json:"rearview_remember" description:"后视镜记忆"`
	Cosmetic               string `json:"cosmetic" description:"遮阳板化妆镜"`
	RearviewSideTurnLight  string `json:"rearviw_side_turn_light" description:"后视镜带侧转向灯"`
}

type TGdAirconditionInfo struct {
	Id                         int64  `json:"-" description:""`
	UtStyleId                  int64  `json:"ut_style_id" description:""`
	AirconditionControlType    string `json:"aircondition_control_type" description:"空调控制类型"`
	BackAirPort                string `json:"back_air_port" description:"后排风出口"`
	FrontTemperatureDistrict   string `json:"front_temperature_district" description:"前排温度分区控制"`
	BackIndependentTemperature string `json:"back_independent_temperature" description:"后排独立温区控制"`
	AirAdjust                  string `json:"air_adjust" description:"空气调节/花粉过滤"`
	Refrigerator               string `json:"refrigerator" description:"车载冰箱"`
	GloveBox                   string `json:"glove_box" description:"风冷手套"`
}

type VehicleBaseInfo struct {
	Id                          int64  `json:"id" description:"唯一编号"`
	SerialNumber                string `json:"serial_number" description:"型号"`
	PlateNo                     string `json:"plate_no" description:"车牌号码"`
	Vin                         string `json:"vin" description:"车辆识别代码"`
	BrandName                   string `json:"brand_name" description:"品牌"`
	PlateType                   string `json:"plate_type" description:"号牌种类"`
	ModelNo                     string `json:"model_no" description:"车辆型号"`
	EngineNo                    string `json:"engine_no" description:"发动机号"`
	VehicleType                 string `json:"vehicle_type" description:"车辆类型"`
	VehicleBodyColor            string `json:"vehicle_body_color" description:"车身颜色"`
	UseProperty                 string `json:"use_property" description:"使用性质"`
	Owner                       string `json:"owner" description:"所有人"`
	InitialRegistrationData     string `json:"initial_registration_data" description:"初次登记日期"`
	InspectionResultEffectiveTo string `json:"inspection_result_effective_to" description:"检验有效期止"`
	CompulsoryScrapTo           string `json:"compulsory_scrap_to" description:"强制报废日期"`
	State                       string `json:"state" description:"状态"`
	EngineType                  string `json:"engine_type" description:"发动机型号"`
	FuelType                    string `json:"fuel_type" description:"燃料种类"`
	Displacement                int64  `json:"displacement" description:"排量"`
	RatedPower                  int64  `json:"rated_power" description:"功率"`
	AxleNumber                  int64  `json:"axle_number" description:"轴数"`
	WheelBase                   int64  `json:"wheel_base" description:"轴距"`
	FrontWheelDistance          int64  `json:"front_wheel_distance" description:"前轮距"`
	BackWheelDistance           int64  `json:"back_wheel_distance" description:"后轮距"`
	GrossMass                   int64  `json:"gross_mass" description:"总质量"`
	UnladenMass                 int64  `json:"unladen_mass" description:"装备质量"`
	ApprovedLoad                int64  `json:"approved_load" description:"核定载客量"`
	ApprovedNumber              int64  `json:"approved_number" description:"核定载客"`
	ReleaseDate                 string `json:"release_date" description:"出厂日期"`
	CreateTime                  string `json:"create_time" description:""`
	UpdateTime                  string `json:"update_time" description:""`
	IsOwner                     string `json:"is_owner" orm:"-" description:"是否是车主 1 //机动车所有人匹配标识 1 匹配 / -1 不匹配 / 0 接口未返回车主姓名"` //
}

func (u *VehicleBaseInfo) TableName() string {
	return "t_gd_vehicle_base_info"
}

type VechicleVerifyOwnerReq struct {
	PlateNo   string `json:"plate_no" description:"车牌号码"`
	PlateType string `json:"plate_type" description:"车牌种类"`
	Owner     string `json:"owner" description:"车辆所有人"`
	AppKey    string `json:"app_key" description:"数据智能平台appkey"`
}

type VechicleVerifyOwnerReply struct {
	IsOwner string `json:"is_owner" description:"是否是车主 "1" //机动车所有人匹配标识 1 匹配 / -1 不匹配 / 0 接口未返回车主姓名"`
}

type VechiclePlateType struct {
	Id        int64  `json:"-" description:"唯一号"`
	Code      string `json:"code" description:"车牌型号编码号"`
	PlateType string `json:"plate_type" description:"车牌型号"`
}

func (v *VechiclePlateType) TableName() string {
	return "t_gd_plate_type_item"
}

type VehicleProvince struct {
	Id       int64  `json:"-" description:"唯一号"`
	Code     string `json:"code" description:"省份短名"`
	Province string `json:"province" description:"省份长名"`
}

func (v *VehicleProvince) TableName() string {
	return "t_gd_province_item"
}

type VehicleBodyColor struct {
	Id           int64  `json:"-" description:"唯一号"`
	Code         string `json:"code" description:"车身颜色代号"`
	VehicleColor string `json:"vehicle_color" description:"车身颜色"`
}

func (v *VehicleBodyColor) TableName() string {
	return "t_gd_vehicle_color_item"
}

type VehicleFuelType struct {
	Id       int64  `json:"-" description:"唯一号"`
	Code     string `json:"code" description:"燃油代号"`
	FuelType string `json:"fuel_type" description:"燃油类型"`
}

func (v *VehicleFuelType) TableName() string {
	return "t_gd_vehicle_fuel_type_item"
}

type VehicleState struct {
	Id           int64  `json:"-" description:"唯一号"`
	Code         string `json:"code" description:"车辆状态代号"`
	VehicleState string `json:"vehicle_state" description:"车辆状态"`
}

func (v *VehicleState) TableName() string {
	return "t_gd_vehicle_state_item"
}

type VehicleType struct {
	Id          int64  `json:"-" description:"唯一号"`
	Code        string `json:"code" description:"车辆类型代号"`
	VehicleType string `json:"vehicle_type" description:"车辆类型"`
}

func (v *VehicleType) TableName() string {
	return "t_gd_vehicle_type_item"
}

type VehicleUseProperty struct {
	Id          int64  `json:"-" description:"唯一号"`
	Code        string `json:"code" description:"车辆使用性质代号"`
	UseProperty string `json:"use_property" description:"车辆使用性质"`
}

type VehicleGetBrandInfoReq struct {
	PlateNo   string `json:"plate_no" description:"车牌号"`
	BrandName string `json:"brand_name" description:"品牌名"`
}

type BrandInfo struct {
	Id              int64  `json:"-"`
	BrandId         string `json:"brand_id"`
	BrandName       string `json:"brand_name"`
	Initial         string `json:"-"`
	C300UpdatedTime string `json:"-"`
	CreatedTime     string `json:"-"`
	UpdatedTime     string `json:"-"`
}
type VehicleGetBrandInfoReply struct {
	Brand BrandInfo `json:"brand"`
}
